@@ -1,6 +1,6 @@
 package Fey::Role::ColumnLike;
 BEGIN {
-  $Fey::Role::ColumnLike::VERSION = '0.35';
+  $Fey::Role::ColumnLike::VERSION = '0.36';
 }
 
 use strict;
@@ -13,10 +13,10 @@ use Moose::Role;
 # do these four roles, but the implementation is different for
 # column-like things (than for example, selectable things).
 with(
-    'Fey::Role::Selectable' => { excludes => 'is_selectable' },
-    'Fey::Role::Comparable' => { excludes => 'is_comparable' },
-    'Fey::Role::Groupable'  => { excludes => 'is_groupable' },
-    'Fey::Role::Orderable'  => { excludes => 'is_orderable' },
+    'Fey::Role::Selectable' => { -excludes => 'is_selectable' },
+    'Fey::Role::Comparable' => { -excludes => 'is_comparable' },
+    'Fey::Role::Groupable'  => { -excludes => 'is_groupable' },
+    'Fey::Role::Orderable'  => { -excludes => 'is_orderable' },
 );
 
 requires '_build_id', 'is_alias';
@@ -49,7 +49,7 @@ Fey::Role::ColumnLike - A role for "column-like" behavior
 
 =head1 VERSION
 
-version 0.35
+version 0.36
 
 =head1 SYNOPSIS
 
