@@ -1,6 +1,6 @@
 package Fey::SQL::Update;
 BEGIN {
-  $Fey::SQL::Update::VERSION = '0.35';
+  $Fey::SQL::Update::VERSION = '0.36';
 }
 
 use strict;
@@ -23,13 +23,13 @@ use MooseX::StrictConstructor;
 with 'Fey::Role::SQL::HasOrderByClause', 'Fey::Role::SQL::HasLimitClause';
 
 with 'Fey::Role::SQL::HasWhereClause' => {
-    excludes => 'bind_params',
-    alias    => { bind_params => '_where_clause_bind_params' },
+    -excludes => 'bind_params',
+    -alias    => { bind_params => '_where_clause_bind_params' },
 };
 
 with 'Fey::Role::SQL::HasBindParams' => {
-    excludes => 'bind_params',
-    alias    => { bind_params => '_update_bind_params' },
+    -excludes => 'bind_params',
+    -alias    => { bind_params => '_update_bind_params' },
 };
 
 has '_update' => (
@@ -190,7 +190,7 @@ Fey::SQL::Update - Represents a UPDATE query
 
 =head1 VERSION
 
-version 0.35
+version 0.36
 
 =head1 SYNOPSIS
 
